@@ -23,6 +23,8 @@
 #include "gailnotebookpage.h"
 #include "gailcanvaswidget.h"
 
+extern GtkWidget *focus_widget;
+
 static void gail_widget_class_init (GailWidgetClass *klass);
 
 static void gail_widget_connect_widget_destroyed (GtkAccessible    *accessible);
@@ -543,7 +545,7 @@ gail_widget_ref_state_set (AtkObject *accessible)
             }
         }
   
-      if (GTK_WIDGET_HAS_FOCUS (widget))
+      if (GTK_WIDGET_HAS_FOCUS (widget) && (widget == focus_widget))
         {
           AtkObject *focus_obj;
 
